@@ -1,7 +1,7 @@
 from ploomber.sources.sources import (SQLScriptSource, SQLQuerySource,
                                       GenericSource, FileSource, EmptySource)
-from ploomber.sources.NotebookSource import NotebookSource
-from ploomber.sources.PythonCallableSource import PythonCallableSource
+from ploomber.sources.notebooksource import NotebookSource
+from ploomber.sources.pythoncallablesource import PythonCallableSource
 
 __all__ = [
     'PythonCallableSource', 'SQLScriptSource', 'SQLQuerySource',
