@@ -329,6 +329,18 @@ class DAGSpec(MutableMapping):
                 imported = yaml.safe_load(
                     Path(self.data['meta']['import_tasks_from']).read_text())
 
+                if not imported:
+                    path = str(self.data['meta']['import_tasks_from'])
+                    raise ValueError('expected import_tasks_from file '
+                                     f'({path!r}) to return a list of tasks, '
+                                     f'got: {imported}')
+
+                if not isinstance(imported, list):
+                    raise TypeError(
+                        'Expected list when loading YAML file from '
+                        'import_tasks_from: file.yaml, '
+                        f'but got {type(imported)}')
+
                 if self.env is not None:
                     (imported,
                      tags_other) = expand_raw_dictionaries_and_extract_tags(
@@ -507,7 +519,7 @@ class DAGSpec(MutableMapping):
         return self._path
 
     @classmethod
-    def _find_relative(cls, name=None):
+    def _find_relative(cls, name=None, lazy_import=False):
         """
         Searches for a spec in default locations relative to the current
         working directory
@@ -520,7 +532,7 @@ class DAGSpec(MutableMapping):
         in "ploomber task --entry-point {relative-path}" when executing tasks
         """
         relative_path = default.entry_point_relative(name=name)
-        return cls(relative_path), relative_path
+        return cls(relative_path, lazy_import=lazy_import), relative_path
 
     @classmethod
     def find(cls,
