@@ -5,31 +5,25 @@ import tempfile
 import subprocess
 from subprocess import PIPE
 from pathlib import Path
-from nbconvert import ExporterNameError
+from importlib.util import find_spec
 import warnings
 
-try:
-    # papermill is importing a deprecated module from pyarrow
-    with warnings.catch_warnings():
-        warnings.simplefilter('ignore', FutureWarning)
-        import papermill as pm
-except ImportError:
-    pm = None
+import jupytext
+import nbformat
+import nbconvert
+from nbconvert import ExporterNameError
+from nbconvert.exporters.webpdf import WebPDFExporter
+
+# papermill is importing a deprecated module from pyarrow
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore', FutureWarning)
+    import papermill as pm
 
 try:
-    import jupytext
+    # this is an optional dependency
+    from pyppeteer import chromium_downloader
 except ImportError:
-    jupytext = None
-
-try:
-    import nbformat
-except ImportError:
-    nbformat = None
-
-try:
-    import nbconvert
-except ImportError:
-    nbconvert = None
+    chromium_downloader = None
 
 from ploomber.exceptions import TaskBuildError, TaskInitializationError
 from ploomber.sources import NotebookSource
@@ -88,6 +82,30 @@ product:
                 'and any other output paths in other keys)')
 
 
+def _check_exporter(exporter, path_to_output):
+    """
+    Validate if the user can use the selected exporter
+    """
+    if exporter is WebPDFExporter:
+        pyppeteer_installed = find_spec('pyppeteer') is not None
+
+        if not pyppeteer_installed:
+            raise TaskInitializationError(
+                'pyppeteer is required to use '
+                'webpdf, install it '
+                'with:\npip install "nbconvert[webpdf]"')
+        else:
+            if not chromium_downloader.check_chromium():
+                chromium_downloader.download_chromium()
+
+        if Path(path_to_output).suffix != '.pdf':
+            raise TaskInitializationError(
+                'Expected output to have '
+                'extension .pdf when using the webpdf '
+                f'exporter, got: {path_to_output}. Change the extension '
+                'and try again')
+
+
 class NotebookConverter:
     """
     Thin wrapper around nbconvert to provide a simple API to convert .ipynb
@@ -148,6 +166,7 @@ class NotebookConverter:
                     _suggest_passing_product_dictionary())
 
         self._exporter = self._get_exporter(exporter_name, path_to_output)
+
         self._path_to_output = path_to_output
         self._nbconvert_export_kwargs = nbconvert_export_kwargs or {}
 
@@ -189,6 +208,7 @@ class NotebookConverter:
         else:
             try:
                 exporter = nbconvert.get_exporter(exporter_name)
+
             # nbconvert 5.6.1 raises ValueError, beginning in version 6,
             # it raises ExporterNameError. However the exception is defined
             # since 5.6.1 so we can safely import it
@@ -205,6 +225,8 @@ class NotebookConverter:
                     "Choose one from: "
                     f'{pretty_print.iterable(names)}')
 
+        _check_exporter(exporter, path_to_output)
+
         return exporter
 
     @staticmethod
